import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'
import businessRouter from './modules/business'
import fms from './modules/fms'
import ums from './modules/ums'
import outlet from './modules/outlet'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },

  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  }
]

export const asyncRoutes = [
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    children: [{
      path: 'dashboard',
      name: 'Dashboard',
      component: () => import('@/views/dashboard/index'),
      meta: { title: '首页', icon: 'el-icon-s-home' }
    }]
  },
  {
    path: '/icon',
    component: Layout,
    redirect: '/icon/list',
    hidden: true,
    children: [{
      path: 'list',
      name: 'icon',
      component: () => import('@/views/icons/index'),
      meta: { title: 'icon', icon: 'el-icon-s-grid' }
    }]
  },
  businessRouter,
  fms,
  ums,
  outlet,
  {
    path: '/sys',
    component: Layout,
    redirect: 'noRedirect',
    alwaysShow: true,
    name: 'sys',
    meta: { title: '系统设置', icon: 'lock', roleValue: 'sys_set' },
    children: [
      {
        path: 'project/list',
        name: 'project',
        component: () => import('@/views/project/index'),
        meta: { title: '项目列表', roleValue: 'project_list_show' }
      },
      {
        path: 'department/list',
        name: 'department',
        component: () => import('@/views/department/index'),
        meta: { title: '部门列表', roleValue: 'department_list_show' }
      },
      {
        path: 'roles/list',
        name: 'roles',
        component: () => import('@/views/roles/index'),
        meta: { title: '角色列表', roleValue: 'roles_list_show' }
      },
      {
        path: 'user/list',
        name: 'user',
        component: () => import('@/views/user/index'),
        meta: { title: '用户列表', roleValue: 'user_list_show' }
      }
    ]
  },
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  mode: 'history',
  scrollBehavior (to, from, savedPosition) {
    if (to.hash) {
      return {
        selector: to.hash
      }
    }
    // keep-alive 返回缓存页面后记录浏览位置
    if (savedPosition && to.meta.keepAlive) {
      return savedPosition
    }
    // 异步滚动操作
    return new Promise((resolve) => {
      setTimeout(() => {
        resolve({ x: 0, y: 1 })
      }, 0)
    })
  },
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter () {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
